@@ -174,8 +174,14 @@ class BaseController extends ActionController {
      * Action for Standard Searchbox
      */
     public function searchAction(){
-        $cacheIdentifier = strtolower($this->settings['search']['layout']).'_search_' . $this->filter->getCacheIdentifier();
-
+		
+		// this fix multilanguge sites 
+		if(isset($this->getLanguageUid()) && null !== $this->getLanguageUid()) {
+			$cacheIdentifier = 'search_'.$this->settings['search']['layout'].'_'.implode('', $this->settings['show']).'_'.$this->settings['search']['layout'].'_L'.$this->getLanguageUid();
+		} else {
+			$cacheIdentifier = strtolower($this->settings['search']['layout']).'_search_' . $this->filter->getCacheIdentifier();
+		}
+        
         if (($entry = $this->cache->get($cacheIdentifier)) === FALSE) {
             $kindOfObjectUids = explode(',', $this->settings['search']['kindOfObjects']);
             foreach ($kindOfObjectUids as $kindOfObjectUid){
@@ -314,7 +320,7 @@ class BaseController extends ActionController {
             if (($entry = $this->cache->get($cacheIdentifier)) === FALSE) {
                 $realty = $this->immobilieRepository->findOneByUrlIdentifier($this->request->getArgument('realty'));
                 $this->view->assign('realty', $realty);
-
+                $this->view->assign('filter', $this->filter);
                 $entry = $this->view->render();
 
                 $tags = array('detail');
@@ -563,6 +569,14 @@ class BaseController extends ActionController {
                         $this->processContactForm();
                     }
                     break;
+                case 'getDistance':
+                    if ($this->request->hasArgument('realtyUid')){
+                        $realty = $this->immobilieRepository->findOneByUid($this->request->getArgument('realtyUid'));
+                        if ($realty instanceof Immobilie){
+                            $this->view->assign('distance', $this->calcDistance($realty->getObjektBreitengrad(), $realty->getObjektLaengengrad(), $this->filter->getLatitude(), $this->filter->getLongitude()));
+                        }
+                    }
+                    break;
                 default:
                     break;
             }
@@ -576,6 +590,21 @@ class BaseController extends ActionController {
      * Internal & Helper Functions
      *********************************************/
 
+    private function calcDistance($latitudePoint1, $longitudePoint1, $latitudePoint2, $longitudePoint2){
+        $pi80 = M_PI / 180;
+        $latitudePoint1 *= $pi80;
+        $longitudePoint1 *= $pi80;
+        $latitudePoint2 *= $pi80;
+        $longitudePoint2 *= $pi80;
+        $r = 6372.797; // mean radius of Earth in km
+        $dlat = $latitudePoint2 - $latitudePoint1;
+        $dlon = $longitudePoint2 - $longitudePoint1;
+        $a = sin($dlat / 2) * sin($dlat / 2) + cos($latitudePoint1) * cos($latitudePoint2) * sin($dlon / 2) * sin($dlon / 2);
+        $c = 2 * atan2(sqrt($a), sqrt(1 - $a));
+        $km = $r * $c;
+        return $km;
+    }
+
     private function pregenerateContactForm(){
         $this->view->assign('salutationOptions', $this->getSalutationOptions());
     }
@@ -829,6 +858,37 @@ class BaseController extends ActionController {
                     $this->filter->setRadius($this->settings['preset']['search']['radius']);
                 }
             }
+            if (isset($filterValues['addressString']) && $filterValues['addressString'] != ''){
+                $this->filter->setAddressString($filterValues['addressString']);
+            }else{
+                $this->filter->setAddressString('');
+            }
+
+            if (isset($filterValues['personsFrom']) && is_numeric($filterValues['personsFrom']) && $filterValues['personsFrom'] > 0){
+                $this->filter->setPersonsFrom($filterValues['personsFrom']);
+            }else{
+                $this->filter->setPersonsFrom(0);
+            }
+            if (isset($filterValues['personsTo']) && is_numeric($filterValues['personsTo']) && $filterValues['personsTo'] > 0){
+                $this->filter->setPersonsTo($filterValues['personsTo']);
+            }else{
+                $this->filter->setPersonsTo(0);
+            }
+            if (isset($filterValues['persons']) && $filterValues['persons'] != ''){
+                $this->filter->setPersonsString($filterValues['persons']);
+
+                $tempPersonsArray = explode('-', $filterValues['persons']);
+                if (isset($tempPersonsArray[0]) && is_numeric($tempPersonsArray[0]) && $tempPersonsArray[0] > 0){
+                    $this->filter->setPersonsFrom($tempPersonsArray[0]);
+                }else{
+                    $this->filter->setPersonsFrom(0);
+                }
+                if (isset($tempPersonsArray[1]) && is_numeric($tempPersonsArray[1]) && $tempPersonsArray[1] > 0){
+                    $this->filter->setPersonsTo($tempPersonsArray[1]);
+                }else{
+                    $this->filter->setPersonsTo(0);
+                }
+            }
         }else{
             // No Data for Filter in Request
             $filter = $this->sessionHandler->restoreFromSession('filter');
@@ -1069,4 +1129,4 @@ class BaseController extends ActionController {
         $message->send();
         return $message->isSent();
     }
-}
\ No newline at end of file
+}
